@@ -1,7 +1,6 @@
-/* $Id: fsusage.h,v 1.8 1999/02/23 11:42:52 martin Exp $ */
+/* $Id: fsusage.h,v 1.18 2004/03/09 23:28:46 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
-   This file is part of LibGTop 1.0.
 
    Contributed by Martin Baulig <martin@home-of-linux.org>, April 1998.
 
@@ -27,26 +26,29 @@
 #include <glibtop.h>
 #include <glibtop/global.h>
 
-BEGIN_LIBGTOP_DECLS
+G_BEGIN_DECLS
 
 #define GLIBTOP_FSUSAGE_BLOCKS		0
 #define GLIBTOP_FSUSAGE_BFREE		1
 #define GLIBTOP_FSUSAGE_BAVAIL		2
 #define GLIBTOP_FSUSAGE_FILES		3
 #define GLIBTOP_FSUSAGE_FFREE		4
+#define GLIBTOP_FSUSAGE_BLOCK_SIZE	6
 
 #define GLIBTOP_MAX_FSUSAGE		5
 
+
 typedef struct _glibtop_fsusage		glibtop_fsusage;
 
 struct _glibtop_fsusage
 {
-	u_int64_t	flags,
-		blocks,		/* Total blocks. */
+	guint64	flags,
+		blocks,		/* Total number of blocks. */
 		bfree,		/* Free blocks available to superuser. */
 		bavail,		/* Free blocks available to non-superuser. */
 		files,		/* Total file nodes. */
 		ffree;		/* Free file nodes. */
+	int	block_size;	/* Size of a block in bytes. */
 };
 
 #define glibtop_get_fsusage(fsusage,disk)	glibtop_get_fsusage_l(glibtop_global_server, fsusage, disk)
@@ -67,6 +69,6 @@ extern const char *glibtop_descriptions_fsusage [];
 
 #endif
 
-END_LIBGTOP_DECLS
+G_END_DECLS
 
 #endif
