@@ -1,5 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -31,7 +29,7 @@
 
 #define LIBGTOP_VERSION_STRING "Libgtop %s server version %s (%u,%u,%u,%u)."
 
-BEGIN_LIBGTOP_DECLS
+G_BEGIN_DECLS
 
 #if _IN_LIBGTOP
 
@@ -39,6 +37,6 @@ void glibtop_send_version (glibtop *server, int fd);
 
 #endif
 
-END_LIBGTOP_DECLS
+G_END_DECLS
 
 #endif
