@@ -1,4 +1,4 @@
-/* $Id: procargs.c,v 1.6 2003/10/20 15:19:59 hadess Exp $ */
+/* $Id: procargs.c,v 1.7 2004/03/04 15:29:15 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -22,7 +22,7 @@
 */
 
 #include <glibtop/procargs.h>
-#include <libgnome/gnome-i18n.h>
+#include "libgtop-i18n.h"
 
 const char *glibtop_names_proc_args [GLIBTOP_MAX_PROC_ARGS] =
 {
