@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: cpu.c,v 1.13 2003/10/19 16:55:43 carlos Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -34,42 +32,38 @@ static const unsigned long _glibtop_sysdeps_cpu =
 
 /* Init function. */
 
-int
+void
 glibtop_init_cpu_s (glibtop *server)
 {
-    server->sysdeps.cpu = _glibtop_sysdeps_cpu;
-
-    return 0;
+	server->sysdeps.cpu = _glibtop_sysdeps_cpu;
 }
 
 /* Provides information about cpu usage. */
 
-int
+void
 glibtop_get_cpu_s (glibtop *server, glibtop_cpu *buf)
 {
-    struct tbl_sysinfo sysinfo;
-    int ret;
+	struct tbl_sysinfo sysinfo;
+	int ret;
 	
-    glibtop_init_s (&server, GLIBTOP_SYSDEPS_CPU, 0);
+	glibtop_init_s (&server, GLIBTOP_SYSDEPS_CPU, 0);
 
-    memset (buf, 0, sizeof (glibtop_cpu));
+	memset (buf, 0, sizeof (glibtop_cpu));
 	
-    ret = table (TBL_SYSINFO, 0, (char *) &sysinfo, 1,
-		 sizeof (struct tbl_sysinfo)); 
+	ret = table (TBL_SYSINFO, 0, (char *) &sysinfo, 1,
+		     sizeof (struct tbl_sysinfo)); 
 
-    if (ret != 1) return -1;
+	if (ret != 1) return;
 
-    buf->flags = _glibtop_sysdeps_cpu;
+	buf->flags = _glibtop_sysdeps_cpu;
 		
-    buf->user = sysinfo.si_user;
-    buf->nice = sysinfo.si_nice;
-    buf->sys  = sysinfo.si_sys;
-    buf->idle = sysinfo.si_idle;
+	buf->user = sysinfo.si_user;
+	buf->nice = sysinfo.si_nice;
+	buf->sys  = sysinfo.si_sys;
+	buf->idle = sysinfo.si_idle;
 	
-    buf->total = sysinfo.si_user + sysinfo.si_nice +
-	sysinfo.si_sys + sysinfo.si_idle;
+	buf->total = sysinfo.si_user + sysinfo.si_nice +
+		sysinfo.si_sys + sysinfo.si_idle;
 
-    buf->frequency = sysinfo.si_hz;
-
-    return 0;
+	buf->frequency = sysinfo.si_hz;
 }
