@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: swap.c,v 1.13 2003/10/19 16:55:43 carlos Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -33,38 +31,34 @@ static unsigned long _glibtop_sysdeps_swap =
 
 /* Init function. */
 
-int
+void
 glibtop_init_swap_s (glibtop *server)
 {
-    server->sysdeps.swap = _glibtop_sysdeps_swap;
-
-    return 0;
+	server->sysdeps.swap = _glibtop_sysdeps_swap;
 }
 
 /* Provides information about swap usage. */
 
-int
+void
 glibtop_get_swap_s (glibtop *server, glibtop_swap *buf)
 {
-    struct tbl_swapinfo swapinfo;
-    int i;
+	struct tbl_swapinfo swapinfo;
+	int i;
 
-    glibtop_init_s (&server, GLIBTOP_SYSDEPS_SWAP, 0);
+	glibtop_init_s (&server, GLIBTOP_SYSDEPS_SWAP, 0);
 
-    memset (buf, 0, sizeof (glibtop_swap));
+	memset (buf, 0, sizeof (glibtop_swap));
 
-    i = 0;
+	i = 0;
 	
-    while (table (TBL_SWAPINFO, i, (char *) &swapinfo, 1,
-		  sizeof (struct tbl_swapinfo)) > 0) {
-	buf->total += swapinfo.size * getpagesize ();
-	buf->free  += swapinfo.free * getpagesize ();
-	i++;
-    }
+	while (table (TBL_SWAPINFO, i, (char *) &swapinfo, 1,
+		      sizeof (struct tbl_swapinfo)) > 0) {
+		buf->total += swapinfo.size * getpagesize ();
+		buf->free  += swapinfo.free * getpagesize ();
+		i++;
+	}
 
-    buf->flags = _glibtop_sysdeps_swap;
+	buf->flags = _glibtop_sysdeps_swap;
 	
-    buf->used  = buf->total - buf->free;
-
-    return 0;
+	buf->used  = buf->total - buf->free;
 }
